/**
 * 开票申请详情
 */

import { h } from "vue";
import { ElTag } from "element-plus";
import { DescriptionColumns } from "/@/components/BasicDescriptions";

export const INV_TYPE = [
  { value: "1", label: "纸质专用发票", type: "primary" },
  { value: "2", label: "纸质普通发票", type: "success" },
  { value: "3", label: "电子普通发票", type: "primary" },
  { value: "4", label: "电子专用发票", type: "success" }
];

export const OPEN_TYPE = [
  { value: "1", label: "金税开票" },
  { value: "2", label: "金税线下" },
  { value: "3", label: "纯线下" }
];

export const INV_OPEN_STATUS = [
  { value: "0", label: "待财务开票", type: "" },
  { value: "1", label: "待发票验证", type: "warning" },
  { value: "2", label: "待填写物流", type: "warning" },
  { value: "3", label: "开票完成", type: "warning" },
  { value: "4", label: "开票失败/驳回", type: "warning" },
  { value: "5", label: "财务驳回", type: "warning" },
  { value: "6", label: "已退票", type: "warning" },
  { value: "7", label: "金税开票中", type: "warning" }
];

export const INV_OPEN_COLUMNS: DescriptionColumns = [
  {
    field: "invNo",
    label: "发票编号"
  },
  {
    field: "inv_value",
    label: "发票金额"
  },
  {
    field: "inv_out",
    label: "开票业务公司"
  },
  {
    field: "inv_in",
    label: "客户公司"
  },
  {
    field: "apply_name",
    label: "申请人"
  },
  {
    field: "status",
    label: "开票状态",
    render(data) {
      return h(
        ElTag,
        {
          type: INV_OPEN_STATUS.find(s => s.value === data)?.type as any
        },
        {
          default: () =>
            INV_OPEN_STATUS.find(s => s.value === data)?.label || "--"
        }
      );
    }
  },
  {
    field: "inv_type",
    label: "发票类型",
    render(data) {
      return h(
        ElTag,
        {
          type: INV_TYPE.find(s => s.value === data)?.type as any
        },
        {
          default: () => INV_TYPE.find(t => t.value === data)?.label || "--"
        }
      );
    }
  },
  {
    field: "open_type",
    label: "开票方式",
    render(data) {
      return h(ElTag, null, {
        default: () => OPEN_TYPE.find(t => t.value === data)?.label || "--"
      });
    }
  },
  {
    field: "is_ticket",
    label: "是否支持金税",
    render(data) {
      return h(ElTag, null, {
        default: () => (data === "0" ? "不支持" : "支持")
      });
    }
  },
  {
    field: "exam_remark",
    label: "审核备注"
  },
  {
    field: "remark",
    label: "备注"
  },
  {
    field: "email",
    label: "电子邮箱"
  },
  {
    field: "winv_fee",
    label: "未开票"
  },
  {
    field: "ainv_fee",
    label: "已开票"
  },
  {
    field: "post_fee",
    label: "快递费"
  },
  {
    field: "post_code",
    label: "快递编号"
  },
  {
    field: "post_company",
    label: "快递公司"
  },
  {
    field: "buyer_title",
    label: "买方抬头"
  },
  {
    field: "buyer_code",
    label: "买方纳税识别号"
  },
  {
    field: "buyer_addr",
    label: "买方注册地址"
  },
  {
    field: "buyer_mobile",
    label: "买方联系方式"
  },
  {
    field: "buyer_bank",
    label: "买方银行"
  },
  {
    field: "seller_title",
    label: "销售方抬头"
  },
  {
    field: "seller_code",
    label: "销售方纳税识别号"
  },
  {
    field: "seller_addr",
    label: "销售方地址"
  },
  {
    field: "seller_mobile",
    label: "销售方联系方式"
  },
  {
    field: "seller_bank",
    label: "销售方银行"
  },
  {
    field: "seller_bankNo",
    label: "销售方账户"
  },
  {
    field: "voider",
    label: "作废人"
  },
  {
    field: "payee",
    label: "收款人"
  },
  {
    field: "drawer",
    label: "开票人"
  },
  {
    field: "ownerPlace",
    label: "复核人"
  }
];

export const ORDER_COLUMNS = [
  {
    field: "invNo",
    label: "发票编号"
  },
  {
    field: "inv_value",
    label: "发票金额"
  },
  {
    field: "inv_out",
    label: "开票业务公司"
  },
  {
    field: "inv_in",
    label: "客户公司"
  },
  {
    field: "apply_name",
    label: "申请人"
  },
  {
    field: "status",
    label: "开票状态",
    render(data) {
      return h(
        ElTag,
        {
          type: INV_OPEN_STATUS.find(s => s.value === data)?.type as any
        },
        {
          default: () =>
            INV_OPEN_STATUS.find(s => s.value === data)?.label || "--"
        }
      );
    }
  },
  {
    field: "inv_type",
    label: "发票类型",
    render(data) {
      return h(
        ElTag,
        {
          type: INV_TYPE.find(s => s.value === data)?.type as any
        },
        {
          default: () => INV_TYPE.find(t => t.value === data)?.label || "--"
        }
      );
    }
  },
  {
    field: "open_type",
    label: "开票方式",
    render(data) {
      return h(ElTag, null, {
        default: () => OPEN_TYPE.find(t => t.value === data)?.label || "--"
      });
    }
  },
  {
    field: "is_ticket",
    label: "是否支持金税",
    render(data) {
      return h(ElTag, null, {
        default: () => (data === "0" ? "不支持" : "支持")
      });
    }
  },
  {
    field: "exam_remark",
    label: "审核备注"
  },
  {
    field: "remark",
    label: "备注"
  },
  {
    field: "email",
    label: "电子邮箱"
  },
  {
    field: "winv_fee",
    label: "未开票"
  },
  {
    field: "ainv_fee",
    label: "已开票"
  },
  {
    field: "post_fee",
    label: "快递费"
  },
  {
    field: "post_code",
    label: "快递编号"
  },
  {
    field: "post_company",
    label: "快递公司"
  }
];

export const INVOICE_COLUMNS = [
  {
    field: "buyer_title",
    label: "买方抬头"
  },
  {
    field: "buyer_code",
    label: "买方纳税识别号"
  },
  {
    field: "buyer_addr",
    label: "买方注册地址"
  },
  {
    field: "buyer_mobile",
    label: "买方联系方式"
  },
  {
    field: "buyer_bank",
    label: "买方银行"
  },
  {
    field: "seller_title",
    label: "销售方抬头"
  },
  {
    field: "seller_code",
    label: "销售方纳税识别号"
  },
  {
    field: "seller_addr",
    label: "销售方地址"
  },
  {
    field: "seller_mobile",
    label: "销售方联系方式"
  },
  {
    field: "seller_bank",
    label: "销售方银行"
  },
  {
    field: "seller_bankNo",
    label: "销售方账户"
  },
  {
    field: "voider",
    label: "作废人"
  },
  {
    field: "payee",
    label: "收款人"
  },
  {
    field: "drawer",
    label: "开票人"
  },
  {
    field: "ownerPlace",
    label: "复核人"
  }
];
