import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/InvoiceSales/capitalPool";

import dayjs from "dayjs";
import { h } from "vue";
import { ElTag } from "element-plus";
import { CAPITAL_STATUS } from "/@/utils/details/tragelog";
import { xs_order_source_options } from "/@/utils/status";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "资金编号",
    prop: "tradNo",
    width: "175px"
  },
  {
    label: "资金认领编号",
    prop: "logNo",
    width: "180px"
  },
  {
    label: "销售单编号",
    prop: "orderCode",
    width: "175px"
  },
  {
    label: "商品编号",
    prop: "goodNo",
    width: "180px"
  },
  {
    label: "商品名称",
    prop: "goodName",
    width: "120px"
  },
  {
    label: "状态",
    prop: "status",
    width: 95,
    cellRenderer: ({ row }) => {
      return h(ElTag, null, {
        default: () =>
          CAPITAL_STATUS.find(s => s.value === row.status)?.label || "--"
      });
    }
  },
  {
    label: "销售来源",
    prop: "qrdSource",
    width: "95px",
    cellRenderer({ row }) {
      return h(ElTag, null, {
        default: () =>
          xs_order_source_options.find(s => s.value === row.qrdSource)?.label
      });
    }
  },
  {
    label: "平台名称",
    prop: "platName",
    width: "120px"
  },
  {
    label: "交易银行",
    prop: "trade_bank",
    width: "120px"
  },
  {
    label: "交易账户",
    prop: "trade_account",
    width: "120px"
  },
  {
    label: "认领资金总金额",
    prop: "total_fee",
    width: "140px"
  },
  {
    label: "申请人",
    prop: "apply_name"
  },
  {
    label: "交易时间",
    prop: "trade_time",
    width: "120px"
  },
  {
    label: "认领时间",
    prop: "addtime",
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    width: 80,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "资金公海池",
  powers: ["001", "002", "003", "004", "005", "006", "007", "008"],
  columns,
  apis: {
    httpList
  }
};

export default contentConfig;
